# ourchester

## Usage example

```bash

# index my notes
ourchester index ~/pdev/taylormonacelli/notes/ '/Users/mtm/Documents/Obsidian Vault'

# find notes where eleastic and test occur together or where wheat berry recipe that i like is
ourchester search '"elastic test"~100'
ourchester search '"berries wheat"~4'

# show where whoosh index is stored
ourchester config

```